@@ -29,27 +29,39 @@ import json
 
 DEFAULT_LOCALE = 'en_US.UTF-8'
 WINDOWS_DEFAULT_LOCALE = 'English'
-LOCALE_SYNONYMS = {'en': ['en_US', 'en-US', 'en_US.UTF8', 'en_US.UTF-8',
-                          'English_United States.1252', 'en-us', 'en_us'],
+LOCALE_SYNONYMS = {'en': [['en_US', 'en-US', 'en_US.UTF8', 'en_US.UTF-8',
+                          'English_United States.1252', 'en-us', 'en_us',
+                          'en_US.utf8'],
+                          ['en_GB', 'en-GB', 'en_GB.UTF8', 'en_GB.UTF-8',
+                          'English_United Kingdom.1252', 'en-gb', 'en_gb',
+                          'en_GB.utf8']],
                    'es': ['es_ES', 'es-ES', 'es_ES.UTF8', 'es_ES.UTF-8',
-                          'Spanish_Spain.1252', 'es-es', 'es_es'],
+                          'Spanish_Spain.1252', 'es-es', 'es_es',
+                          'es_ES.utf8'],
                    'sp': ['es_ES', 'es-ES', 'es_ES.UTF8', 'es_ES.UTF-8',
-                          'Spanish_Spain.1252', 'es-es', 'es_es'],
+                          'Spanish_Spain.1252', 'es-es', 'es_es',
+                          'es_ES.utf8'],
                    'fr': [['fr_FR', 'fr-FR', 'fr_BE', 'fr_CH', 'fr-BE',
                            'fr-CH', 'fr_FR.UTF8', 'fr_CH.UTF8',
                            'fr_BE.UTF8', 'fr_FR.UTF-8', 'fr_CH.UTF-8',
                            'fr_BE.UTF-8', 'French_France.1252', 'fr-fr',
-                           'fr_fr', 'fr-be', 'fr_be', 'fr-ch', 'fr_ch'],
+                           'fr_fr', 'fr-be', 'fr_be', 'fr-ch', 'fr_ch',
+                           'fr_FR.utf8', 'fr_BE.utf8', 'fr_CH.utf8'],
                           ['fr_CA', 'fr-CA', 'fr_CA.UTF8', 'fr_CA.UTF-8',
-                           'French_Canada.1252', 'fr-ca', 'fr_ca']],
+                           'French_Canada.1252', 'fr-ca', 'fr_ca',
+                           'fr_CA.utf8']],
                    'de': ['de_DE', 'de-DE', 'de_DE.UTF8', 'de_DE.UTF-8',
-                          'German_Germany.1252', 'de-de', 'de_de'],
+                          'German_Germany.1252', 'de-de', 'de_de',
+                          'de_DE.utf8'],
                    'ge': ['de_DE', 'de-DE', 'de_DE.UTF8', 'de_DE.UTF-8',
-                          'German_Germany.1252', 'de-de', 'de_de'],
+                          'German_Germany.1252', 'de-de', 'de_de',
+                          'de_DE.utf8'],
                    'it': ['it_IT', 'it-IT', 'it_IT.UTF8', 'it_IT.UTF-8',
-                          'Italian_Italy.1252', 'it-it', 'it_it'],
+                          'Italian_Italy.1252', 'it-it', 'it_it',
+                          'it_IT.utf8'],
                    'ca': ['ca_ES', 'ca-ES', 'ca_ES.UTF8', 'ca_ES.UTF-8',
-                          'Catalan_Spain.1252', 'ca-es', 'ca_es']}
+                          'Catalan_Spain.1252', 'ca-es', 'ca_es',
+                          'ca_ES.utf8']}
 
 BOLD_REGEX = re.compile(r'''(\*\*)(?=\S)([^\r]*?\S[*_]*)\1''')
 ITALIC_REGEX = re.compile(r'''(_)(?=\S)([^\r]*?\S)\1''')
